@@ -27,11 +27,11 @@ protected:
 public:
 virtual void apply_start() {};
 // handler functions
-virtual void node(const osmium::Node&) const = 0;
-virtual void way(const osmium::Way&) const = 0;
-virtual void relation(const osmium::Relation&) const = 0;
-virtual void changeset(const osmium::Changeset&) const = 0;
-virtual void area(const osmium::Area&) const = 0;
+virtual void node(const osmium::Node&) = 0;
+virtual void way(const osmium::Way&) = 0;
+virtual void relation(const osmium::Relation&) = 0;
+virtual void changeset(const osmium::Changeset&) = 0;
+virtual void area(const osmium::Area&) = 0;
 
 
 private:
@@ -104,7 +104,7 @@ using namespace boost::python;
 
 struct SimpleHandlerWrap: BaseHandler, wrapper<BaseHandler> {
 
-    void node(const osmium::Node& node) const {
+    void node(const osmium::Node& node) override {
         if (!(m_callbacks & osmium::osm_entity_bits::node))
             return;
 
@@ -113,7 +113,7 @@ struct SimpleHandlerWrap: BaseHandler, wrapper<BaseHandler> {
         }
     }
 
-    void way(const osmium::Way& way) const {
+    void way(const osmium::Way& way) {
         if (!(m_callbacks & osmium::osm_entity_bits::way))
             return;
 
@@ -121,7 +121,7 @@ struct SimpleHandlerWrap: BaseHandler, wrapper<BaseHandler> {
             f(boost::ref(way));
     }
 
-    void relation(const osmium::Relation& rel) const {
+    void relation(const osmium::Relation& rel) {
         if (!(m_callbacks & osmium::osm_entity_bits::relation))
             return;
 
@@ -129,7 +129,7 @@ struct SimpleHandlerWrap: BaseHandler, wrapper<BaseHandler> {
             f(boost::ref(rel));
     }
 
-    void changeset(const osmium::Changeset& cs) const {
+    void changeset(const osmium::Changeset& cs) {
         if (!(m_callbacks & osmium::osm_entity_bits::changeset))
             return;
 
@@ -137,7 +137,7 @@ struct SimpleHandlerWrap: BaseHandler, wrapper<BaseHandler> {
             f(boost::ref(cs));
     }
 
-    void area(const osmium::Area& area) const {
+    void area(const osmium::Area& area) {
         if (!(m_callbacks & osmium::osm_entity_bits::area))
             return;
 
