@@ -57,6 +57,14 @@ class TestNodePositiveId(HandlerTestBase, unittest.TestCase):
         def node(self, n):
             assert_equals(n.positive_id(), 34)
 
+class TestNodeLargeId(HandlerTestBase, unittest.TestCase):
+    data = [osmobj('N', id=17179869418, version=5, changeset=58674, uid=42,
+                   timestamp='2014-01-31T06:23:35Z', user='anonymous')]
+
+    class Handler(o.SimpleHandler):
+        def node(self, n):
+            assert_equals(n.id, 17179869418)
+
 
 class TestWayAttributes(HandlerTestBase, unittest.TestCase):
 
@@ -134,7 +142,7 @@ class TestAreaFromWayAttributes(HandlerTestBase, unittest.TestCase):
             assert_true(oring.is_closed())
             assert_true(oring.ends_have_same_id())
             assert_true(oring.ends_have_same_location())
-            assert_equals(len(list(n.inner_rings())), 0)
+            assert_equals(len(list(n.inner_rings(oring))), 0)
 
 class TestChangesetAttributes(HandlerTestBase, unittest.TestCase):
     data = [osmobj('C', id=34, created_at="2005-04-09T19:54:13Z",
